**This is a fork of the original, stale project to fix some of the issues, add some unit-tests, and to push to PyPI.**

blockhash-python
================

This is a perceptual image hash calculation tool based on algorithm descibed in
Block Mean Value Based Image Perceptual Hashing by Bian Yang, Fan Gu and Xiamu Niu.

Usage
-----

This script requires Python 2.x or Python 3 and Python Imaging (PIL) 1.1.6 or above.

Run `blockhash.py [list of images]` for calculating hashes.

Run `blockhash.py --help` for the list of options.

License
-------

Copyright 2014 Commons Machinery http://commonsmachinery.se/

Distributed under an MIT license, please see LICENSE in the top dir.

Contact: dev@commonsmachinery.se
